@@ -1,5 +1,5 @@
 package Playwright;
-$Playwright::VERSION = '1.291';
+$Playwright::VERSION = '1.323';
 use strict;
 use warnings;
 
@@ -308,7 +308,7 @@ Playwright - Perl client for Playwright
 
 =head1 VERSION
 
-version 1.291
+version 1.323
 
 =head1 SYNOPSIS
 
@@ -331,6 +331,13 @@ version 1.291
 
     my $kids = $body->selectMulti('*');
 
+    #Alternatively, use the new locator API instead of select/selectMulti:
+    my $loc = $page->locator('body');
+    my $innerTubes = $loc->allInnerTexts();
+    print Dumper($innerTubes);
+
+    # See a more full exploration of the API in example.pl on github.
+
 =head1 DESCRIPTION
 
 Perl interface to a lightweight node.js webserver that proxies commands runnable by Playwright.
@@ -734,6 +741,12 @@ George S. Baugh <teodesian@gmail.com>
 
 =back
 
+=head1 CONTRIBUTOR
+
+=for stopwords Yanick Champoux
+
+Yanick Champoux <yanick.champoux@iinteractive.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2020 Troglodyne LLC
