@@ -3,60 +3,62 @@
 # You should not use this directly; use Playwright instead.
 
 package Playwright::ModuleList;
-$Playwright::ModuleList::VERSION = '1.291';
+$Playwright::ModuleList::VERSION = '1.323';
 use strict;
 use warnings;
 
-use Playwright::PageAssertions;
-use Playwright::Response;
-use Playwright::Android;
-use Playwright::APIResponseAssertions;
-use Playwright::Dialog;
-use Playwright::Video;
-use Playwright::Page;
-use Playwright::AndroidDevice;
-use Playwright::Keyboard;
-use Playwright::Browser;
-use Playwright::JSHandle;
-use Playwright::BrowserContext;
-use Playwright::APIResponse;
-use Playwright::APIRequest;
-use Playwright::Tracing;
-use Playwright::Electron;
-use Playwright::ElectronApplication;
 use Playwright::SnapshotAssertions;
-use Playwright::PlaywrightException;
-use Playwright::WebSocketFrame;
 use Playwright::Error;
-use Playwright::FormData;
-use Playwright::Request;
-use Playwright::Route;
-use Playwright::CDPSession;
+use Playwright::AndroidWebView;
+use Playwright::Response;
 use Playwright::Touchscreen;
-use Playwright::BrowserServer;
-use Playwright::Worker;
-use Playwright::Selectors;
 use Playwright::Accessibility;
+use Playwright::WebSocket;
+use Playwright::Tracing;
+use Playwright::PlaywrightAssertions;
+use Playwright::Worker;
+use Playwright::ElectronApplication;
+use Playwright::Electron;
+use Playwright::BrowserContext;
+use Playwright::Logger;
+use Playwright::Mouse;
+use Playwright::GenericAssertions;
+use Playwright::FrameLocator;
+use Playwright::FileChooser;
+use Playwright::PageAssertions;
+use Playwright::Locator;
+use Playwright::APIResponse;
+use Playwright::JSHandle;
+use Playwright::FormData;
+use Playwright::PlaywrightException;
+use Playwright::Frame;
+use Playwright::AndroidInput;
 use Playwright::BrowserType;
 use Playwright::LocatorAssertions;
-use Playwright::FrameLocator;
-use Playwright::PlaywrightAssertions;
-use Playwright::ElementHandle;
-use Playwright::Logger;
-use Playwright::AndroidInput;
-use Playwright::Download;
-use Playwright::Frame;
-use Playwright::RequestOptions;
-use Playwright::AndroidWebView;
-use Playwright::FileChooser;
-use Playwright::Locator;
-use Playwright::Coverage;
-use Playwright::APIRequestContext;
-use Playwright::TimeoutError;
-use Playwright::AndroidSocket;
-use Playwright::WebSocket;
+use Playwright::WebSocketFrame;
 use Playwright::ConsoleMessage;
-use Playwright::Mouse;
+use Playwright::RequestOptions;
+use Playwright::APIResponseAssertions;
+use Playwright::Download;
+use Playwright::AndroidSocket;
+use Playwright::CDPSessionEvent;
+use Playwright::Selectors;
+use Playwright::Page;
+use Playwright::APIRequestContext;
+use Playwright::AndroidDevice;
+use Playwright::BrowserServer;
+use Playwright::Dialog;
+use Playwright::Coverage;
+use Playwright::ElementHandle;
+use Playwright::Android;
+use Playwright::Request;
+use Playwright::APIRequest;
+use Playwright::TimeoutError;
+use Playwright::Keyboard;
+use Playwright::Route;
+use Playwright::Browser;
+use Playwright::Video;
+use Playwright::CDPSession;
 use Playwright::Mouse;
 use Playwright::Keyboard;
 
@@ -74,7 +76,7 @@ Playwright::ModuleList - Playwright sub classes.
 
 =head1 VERSION
 
-version 1.291
+version 1.323
 
 =head1 SEE ALSO
 
