@@ -1,5 +1,5 @@
 package Playwright::Util;
-$Playwright::Util::VERSION = '1.291';
+$Playwright::Util::VERSION = '1.323';
 use strict;
 use warnings;
 
@@ -58,10 +58,10 @@ sub arr2hash ( $array, $primary_key, $callback = '' ) {
 sub async ($subroutine) {
 
     # The fork would result in the tmpdir getting whacked when it terminates.
-    my ( undef, $filename ) = File::Temp::tempfile();
+    my $fh  = File::Temp->new();
     my $pid = fork() // die "Could not fork";
-    _child( $filename, $subroutine ) unless $pid;
-    return { pid => $pid, file => $filename };
+    _child( $fh->filename, $subroutine ) unless $pid;
+    return { pid => $pid, file => $fh };
 }
 
 sub _child ( $filename, $subroutine ) {
@@ -74,8 +74,8 @@ sub _child ( $filename, $subroutine ) {
 sub await ($to_wait) {
     waitpid( $to_wait->{pid}, 0 );
     confess("Timed out while waiting for event.")
-      unless -f $to_wait->{file} && -s _;
-    return Sereal::Decoder->decode_from_file( $to_wait->{file} );
+      unless -f $to_wait->{file}->filename && -s _;
+    return Sereal::Decoder->decode_from_file( $to_wait->{file}->filename );
 }
 
 1;
@@ -92,7 +92,7 @@ Playwright::Util - Common utility functions for the Playwright module
 
 =head1 VERSION
 
-version 1.291
+version 1.323
 
 =head2 request(STRING method, STRING url, STRING host, INTEGER port, LWP::UserAgent ua, HASH args) = HASH
 
